##  Integration with Configuration Management Databases (CMDB)
If your organization maintains CMDB, SAP LeanIX offers seamless integration options. Integration with your existing CMDB ensures that SAP LeanIX is continuously updated with the latest information, providing a real-time view of your technology landscape. At the minimum, ensure that you obtain IT component names, versions, and the application - IT component relationships.
To learn about using APIs for importing and exporting data, see [Importing and Exporting Data](https://help.sap.com/docs/leanix/ea/importing-and-exporting-data?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to import and export data between your organization's system and SAP LeanIX."). To learn about SAP LeanIX integration APIs, see [Integration API](https://help.sap.com/docs/leanix/ea/integration-api?locale=en-US&state=PRODUCTION&version=CLOUD "Overview of the Integration API.").
